@@ -195,6 +195,11 @@ class PlominoField(BaseContent, BrowserDefaultMixin):
                 current_files=doc.getItem(fieldname)
                 if current_files=='':
                     current_files={}
+                else:
+                    if adapt.type == "SINGLE":
+                        for filename in current_files.keys():
+                            doc.deletefile(filename)
+                        current_files={}
                 (new_file, contenttype) = doc.setfile(submittedValue)
                 if new_file is not None:
                     current_files[new_file]=contenttype
@@ -316,7 +321,11 @@ class PlominoField(BaseContent, BrowserDefaultMixin):
         if self.FieldType == "RICHTEXT":
             return "text/html"
         return "text/plain"
-        
+    
+    @property
+    def formula_ids(self):
+        return {'Formula':  "field_"+self.getParentNode().id+"_"+self.id,
+                'ValidationFormula': "field_"+self.getParentNode().id+"_"+self.id+"_ValidationFormula"}
 registerType(PlominoField, PROJECTNAME)
 # end of class PlominoField
 
